==> apache-cxf-3.1.15-src.zip: apache-cxf-3.1.15-src/rt/rs/security/sso/oidc/src/test/java/org/apache/cxf/rs/security/oidc/utils/OidcUtilsTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.oidc.utils;

import java.util.List;

import org.apache.cxf.rs.security.oidc.common.UserInfo;

import org.junit.Assert;
import org.junit.Test;

public class OidcUtilsTest extends Assert {
    
    @Test
    public void testScopeToClaimsMappingNoValue() {
        List<String> claims = OidcUtils.getScopeClaims();
        assertNotNull(claims);
        assertEquals(0, claims.size());
    }
    
    @Test
    public void testScopeToClaimsMappingSingleValue() {
        List<String> claims = OidcUtils.getScopeClaims(OidcUtils.PHONE_SCOPE);
        assertNotNull(claims);
        assertEquals(1, claims.size());
        assertEquals(UserInfo.PHONE_CLAIM, claims.get(0));
    }
    
    @Test
    public void testScopeToClaimsMappingMultiValue() {
        List<String> claims = OidcUtils.getScopeClaims(OidcUtils.PROFILE_SCOPE, OidcUtils.PHONE_SCOPE);
        assertNotNull(claims);
        assertEquals(15, claims.size());
    }
        
}

==> apache-cxf-4.0.9-src.zip: apache-cxf-4.0.9-src/rt/rs/security/sso/oidc/src/test/java/org/apache/cxf/rs/security/oidc/utils/OidcUtilsTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.oidc.utils;

import java.util.List;

import org.apache.cxf.rs.security.oidc.common.AbstractUserInfo;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class OidcUtilsTest {
    
    @Test
    public void testScopeToClaimsMappingNoValue() {
        List<String> claims = OidcUtils.getScopeClaims();
        assertNotNull(claims);
        assertEquals(0, claims.size());
    }
    
    @Test
    public void testScopeToClaimsMappingSingleValue() {
        List<String> claims = OidcUtils.getScopeClaims(OidcUtils.PHONE_SCOPE);
        assertNotNull(claims);
        assertEquals(1, claims.size());
        assertEquals(AbstractUserInfo.PHONE_CLAIM, claims.get(0));
    }
    
    @Test
    public void testScopeToClaimsMappingMultiValue() {
        List<String> claims = OidcUtils.getScopeClaims(OidcUtils.PROFILE_SCOPE, OidcUtils.PHONE_SCOPE);
        assertNotNull(claims);
        assertEquals(15, claims.size());
    }
        
}
